**v0.1.0 (2024-08-06)**

* README.rst に開発ツールのインストールと使い方の説明を追加しました。
* 廃止予定の `pkg_resources` のかわりに `importlib.metadata` を使うように修正しました。
* The Uncompromising Code Formatter black を使ってソースコードを整形しました。


**v0.1.0a4 (2023-09-20)**

* パッケージのビルドに必要なデータは pyproject.toml で定義するように変更しました。(PEP 518)


**v0.1.0a3 (2016-04-05)**

* ローダータイプとプロファイルからセッション情報を読み込む機能を追加しました。
* 設定解析オブジェクトからセッション情報を読み込む機能を追加しました。
* ユーザーが用意した設定ファイルを読み込む機能を追加しました。


**v0.1.0a2 (2016-02-06)**

* ソースパッケージにドキュメントを追加しました。
* Firefoxのプロファイルからニコニコのセッション情報をロードする機能を追加しました。


**v0.1.0a1 (2015-11-24)**

* コマンド **yan** を追加しました。
  このコマンドはサブコマンドの追加による機能拡張が可能です。
